@@ -3,6 +3,7 @@ __date__ = "December 7, 2012"
 __license__ = "MIT"
 
 import argparse
+import codecs
 import operator
 import sys
 from .Tokenizer import Tokenizer
@@ -10,6 +11,16 @@ from TwitterAPI import TwitterAPI, TwitterOAuth, TwitterRestPager
 from . import Words
 
 
+try:
+	# python 3
+	sys.stdout = codecs.getwriter('utf8')(sys.stdout.buffer)
+	sys.stderr = codecs.getwriter('utf8')(sys.stderr.buffer)
+except:
+	# python 2
+	sys.stdout = codecs.getwriter('utf8')(sys.stdout)
+	sys.stderr = codecs.getwriter('utf8')(sys.stderr)
+
+
 def is_irrelevant_word(word):
 	if word in Words.conj or word in Words.prep or word in Words.pron or word in Words.misc:
 		return True
